@@ -1,10 +1,10 @@
 /* This file is part of                   -*- C++ -*-
-* ====================================================== 
-* 
+* ======================================================
+*
 *           LyX, The Document Processor
-* 	 
-*	    Copyright (C) 1995-1997 Matthias Ettrich 
-*                                    & The LyX team
+*
+*           Copyright 1995 Matthias Ettrich
+*           Copyright 1995-2001 The LyX Team.
 *
 * ====================================================== */
 
@@ -12,16 +12,20 @@
    functions. This should probably be moved into LyXView (to have
    different input methods for different frames, but for now we can
    keep it as it is. */
+#ifndef LYXLOOKUP_H
+#define LYXLOOKUP_H
 
 #include <X11/Xlib.h>
 
-// Initialize the compose key handling
-extern void InitLyXLookup(Display *, Window ) ;
+/// Initialize the compose key handling
+extern void InitLyXLookup(Display *, Window);
 
-// Read a keysym and/or a string (like XLookupString)
-extern int LyXLookupString(XEvent * event,    
+/// Read a keysym and/or a string (like XLookupString)
+extern int LyXLookupString(XEvent * event,
 			   char * buffer_return, int bytes_buffer,
 			   KeySym * keysym_return);
 
-// Call this when you destroy your window
+/// Call this when you destroy your window
 extern void CloseLyXLookup();
+
+#endif
